# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtlab/ui/calc_ui.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(427, 266)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(15, 15, 15, 5)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setFocusPolicy(QtCore.Qt.NoFocus)
        self.tabWidget.setUsesScrollButtons(False)
        self.tabWidget.setDocumentMode(True)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_2.setContentsMargins(15, 15, 15, 15)
        self.gridLayout_2.setHorizontalSpacing(10)
        self.gridLayout_2.setVerticalSpacing(8)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.line_2 = QtWidgets.QFrame(self.tab_3)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setObjectName("line_2")
        self.gridLayout_2.addWidget(self.line_2, 6, 0, 1, 5)
        self.label_20 = QtWidgets.QLabel(self.tab_3)
        self.label_20.setObjectName("label_20")
        self.gridLayout_2.addWidget(self.label_20, 0, 0, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.tab_3)
        self.label_17.setObjectName("label_17")
        self.gridLayout_2.addWidget(self.label_17, 4, 0, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.tab_3)
        self.label_18.setObjectName("label_18")
        self.gridLayout_2.addWidget(self.label_18, 5, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.tab_3)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 7, 0, 1, 1)
        self.molConcCombo = QtWidgets.QComboBox(self.tab_3)
        self.molConcCombo.setObjectName("molConcCombo")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.gridLayout_2.addWidget(self.molConcCombo, 4, 2, 1, 3)
        self.label_19 = QtWidgets.QLabel(self.tab_3)
        self.label_19.setObjectName("label_19")
        self.gridLayout_2.addWidget(self.label_19, 1, 0, 1, 1)
        self.molMWBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molMWBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molMWBox.setDecimals(4)
        self.molMWBox.setMaximum(9999999.0)
        self.molMWBox.setObjectName("molMWBox")
        self.gridLayout_2.addWidget(self.molMWBox, 1, 1, 1, 1)
        self.line_4 = QtWidgets.QFrame(self.tab_3)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setObjectName("line_4")
        self.gridLayout_2.addWidget(self.line_4, 2, 0, 1, 5)
        self.label_5 = QtWidgets.QLabel(self.tab_3)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 7, 2, 1, 1)
        self.molVolCombo = QtWidgets.QComboBox(self.tab_3)
        self.molVolCombo.setObjectName("molVolCombo")
        self.molVolCombo.addItem("")
        self.molVolCombo.addItem("")
        self.molVolCombo.addItem("")
        self.gridLayout_2.addWidget(self.molVolCombo, 5, 2, 1, 3)
        self.molResultBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molResultBox.setReadOnly(True)
        self.molResultBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molResultBox.setDecimals(4)
        self.molResultBox.setMaximum(9999999.0)
        self.molResultBox.setObjectName("molResultBox")
        self.gridLayout_2.addWidget(self.molResultBox, 7, 1, 1, 1)
        self.molClearButton = QtWidgets.QToolButton(self.tab_3)
        self.molClearButton.setAutoRaise(True)
        self.molClearButton.setObjectName("molClearButton")
        self.gridLayout_2.addWidget(self.molClearButton, 7, 4, 1, 1)
        self.molCopyButton = QtWidgets.QToolButton(self.tab_3)
        self.molCopyButton.setAutoRaise(True)
        self.molCopyButton.setObjectName("molCopyButton")
        self.gridLayout_2.addWidget(self.molCopyButton, 7, 3, 1, 1)
        self.frame = QtWidgets.QFrame(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setObjectName("frame")
        self.molInputLayout = QtWidgets.QHBoxLayout(self.frame)
        self.molInputLayout.setContentsMargins(0, 0, 0, 0)
        self.molInputLayout.setObjectName("molInputLayout")
        self.gridLayout_2.addWidget(self.frame, 0, 1, 1, 3)
        self.molDbAddButton = QtWidgets.QToolButton(self.tab_3)
        self.molDbAddButton.setAutoRaise(True)
        self.molDbAddButton.setObjectName("molDbAddButton")
        self.gridLayout_2.addWidget(self.molDbAddButton, 0, 4, 1, 1)
        self.molDbDelButton = QtWidgets.QToolButton(self.tab_3)
        self.molDbDelButton.setAutoRaise(True)
        self.molDbDelButton.setObjectName("molDbDelButton")
        self.gridLayout_2.addWidget(self.molDbDelButton, 1, 4, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.tab_3)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 2, 1, 2)
        self.molConcBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molConcBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molConcBox.setMaximum(9999999.0)
        self.molConcBox.setObjectName("molConcBox")
        self.gridLayout_2.addWidget(self.molConcBox, 4, 1, 1, 1)
        self.molVolBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molVolBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molVolBox.setMaximum(9999999.0)
        self.molVolBox.setObjectName("molVolBox")
        self.gridLayout_2.addWidget(self.molVolBox, 5, 1, 1, 1)
        self.tabWidget.addTab(self.tab_3, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_3.setContentsMargins(15, 15, 15, 15)
        self.gridLayout_3.setHorizontalSpacing(10)
        self.gridLayout_3.setVerticalSpacing(8)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.dilResultBox = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilResultBox.setReadOnly(True)
        self.dilResultBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilResultBox.setMaximum(9999999.0)
        self.dilResultBox.setObjectName("dilResultBox")
        self.gridLayout_3.addWidget(self.dilResultBox, 7, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.tab)
        self.label_10.setObjectName("label_10")
        self.gridLayout_3.addWidget(self.label_10, 5, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.tab)
        self.line.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setObjectName("line")
        self.gridLayout_3.addWidget(self.line, 2, 0, 1, 5)
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 7, 0, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.tab)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_22.setFont(font)
        self.label_22.setObjectName("label_22")
        self.gridLayout_3.addWidget(self.label_22, 0, 0, 1, 1)
        self.dilV2Combo = QtWidgets.QComboBox(self.tab)
        self.dilV2Combo.setObjectName("dilV2Combo")
        self.dilV2Combo.addItem("")
        self.dilV2Combo.addItem("")
        self.dilV2Combo.addItem("")
        self.gridLayout_3.addWidget(self.dilV2Combo, 5, 2, 1, 3)
        self.dilC2Combo = QtWidgets.QComboBox(self.tab)
        self.dilC2Combo.setObjectName("dilC2Combo")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.gridLayout_3.addWidget(self.dilC2Combo, 4, 2, 1, 3)
        self.label_16 = QtWidgets.QLabel(self.tab)
        self.label_16.setObjectName("label_16")
        self.gridLayout_3.addWidget(self.label_16, 4, 0, 1, 1)
        self.line_3 = QtWidgets.QFrame(self.tab)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setObjectName("line_3")
        self.gridLayout_3.addWidget(self.line_3, 6, 0, 1, 5)
        self.dilC1Box = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilC1Box.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilC1Box.setMaximum(9999999.0)
        self.dilC1Box.setObjectName("dilC1Box")
        self.gridLayout_3.addWidget(self.dilC1Box, 1, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.tab)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 1, 0, 1, 1)
        self.dilClearButton = QtWidgets.QToolButton(self.tab)
        self.dilClearButton.setAutoRaise(True)
        self.dilClearButton.setObjectName("dilClearButton")
        self.gridLayout_3.addWidget(self.dilClearButton, 7, 4, 1, 1)
        self.dilC1Combo = QtWidgets.QComboBox(self.tab)
        self.dilC1Combo.setObjectName("dilC1Combo")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.gridLayout_3.addWidget(self.dilC1Combo, 1, 2, 1, 2)
        self.frame_2 = QtWidgets.QFrame(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_2.setObjectName("frame_2")
        self.dilInputLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.dilInputLayout.setContentsMargins(0, 0, 0, 0)
        self.dilInputLayout.setObjectName("dilInputLayout")
        self.gridLayout_3.addWidget(self.frame_2, 0, 1, 1, 3)
        self.dilDbDelButton = QtWidgets.QToolButton(self.tab)
        self.dilDbDelButton.setAutoRaise(True)
        self.dilDbDelButton.setObjectName("dilDbDelButton")
        self.gridLayout_3.addWidget(self.dilDbDelButton, 1, 4, 1, 1)
        self.dilDbAddButton = QtWidgets.QToolButton(self.tab)
        self.dilDbAddButton.setAutoRaise(True)
        self.dilDbAddButton.setObjectName("dilDbAddButton")
        self.gridLayout_3.addWidget(self.dilDbAddButton, 0, 4, 1, 1)
        self.dilC2Box = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilC2Box.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilC2Box.setMaximum(9999999.0)
        self.dilC2Box.setObjectName("dilC2Box")
        self.gridLayout_3.addWidget(self.dilC2Box, 4, 1, 1, 1)
        self.dilV2Box = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilV2Box.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilV2Box.setMaximum(9999999.0)
        self.dilV2Box.setObjectName("dilV2Box")
        self.gridLayout_3.addWidget(self.dilV2Box, 5, 1, 1, 1)
        self.dilResultCombo = QtWidgets.QComboBox(self.tab)
        self.dilResultCombo.setObjectName("dilResultCombo")
        self.dilResultCombo.addItem("")
        self.dilResultCombo.addItem("")
        self.dilResultCombo.addItem("")
        self.gridLayout_3.addWidget(self.dilResultCombo, 7, 2, 1, 2)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.notes = QtWidgets.QPlainTextEdit(self.tab_2)
        self.notes.setObjectName("notes")
        self.horizontalLayout.addWidget(self.notes)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab_4)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.displayFormulaBox = QtWidgets.QCheckBox(self.tab_4)
        self.displayFormulaBox.setObjectName("displayFormulaBox")
        self.verticalLayout_2.addWidget(self.displayFormulaBox)
        self.escapeKeyBox = QtWidgets.QCheckBox(self.tab_4)
        self.escapeKeyBox.setObjectName("escapeKeyBox")
        self.verticalLayout_2.addWidget(self.escapeKeyBox)
        self.copyClipboardBox = QtWidgets.QCheckBox(self.tab_4)
        self.copyClipboardBox.setObjectName("copyClipboardBox")
        self.verticalLayout_2.addWidget(self.copyClipboardBox)
        self.copyNotesBox = QtWidgets.QCheckBox(self.tab_4)
        self.copyNotesBox.setObjectName("copyNotesBox")
        self.verticalLayout_2.addWidget(self.copyNotesBox)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.resetButton = QtWidgets.QPushButton(self.tab_4)
        self.resetButton.setMaximumSize(QtCore.QSize(150, 16777215))
        self.resetButton.setObjectName("resetButton")
        self.verticalLayout_2.addWidget(self.resetButton)
        self.tabWidget.addTab(self.tab_4, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.frame_3 = QtWidgets.QFrame(self.centralwidget)
        self.frame_3.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_3.setObjectName("frame_3")
        self.bottomLayout = QtWidgets.QHBoxLayout(self.frame_3)
        self.bottomLayout.setContentsMargins(0, 0, 0, 0)
        self.bottomLayout.setObjectName("bottomLayout")
        self.statusLabel = QtWidgets.QLabel(self.frame_3)
        self.statusLabel.setText("")
        self.statusLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.statusLabel.setObjectName("statusLabel")
        self.bottomLayout.addWidget(self.statusLabel)
        self.verticalLayout.addWidget(self.frame_3)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.molMWBox, self.molConcBox)
        MainWindow.setTabOrder(self.molConcBox, self.molVolBox)
        MainWindow.setTabOrder(self.molVolBox, self.molResultBox)
        MainWindow.setTabOrder(self.molResultBox, self.molConcCombo)
        MainWindow.setTabOrder(self.molConcCombo, self.molVolCombo)
        MainWindow.setTabOrder(self.molVolCombo, self.dilC1Box)
        MainWindow.setTabOrder(self.dilC1Box, self.dilC2Box)
        MainWindow.setTabOrder(self.dilC2Box, self.dilV2Box)
        MainWindow.setTabOrder(self.dilV2Box, self.dilResultBox)
        MainWindow.setTabOrder(self.dilResultBox, self.dilC1Combo)
        MainWindow.setTabOrder(self.dilC1Combo, self.dilC2Combo)
        MainWindow.setTabOrder(self.dilC2Combo, self.dilV2Combo)
        MainWindow.setTabOrder(self.dilV2Combo, self.notes)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.label_20.setText(_translate("MainWindow", "Reagent name"))
        self.label_17.setText(_translate("MainWindow", "Final concentration"))
        self.label_18.setText(_translate("MainWindow", "Final volume"))
        self.label_3.setText(_translate("MainWindow", "Required mass :"))
        self.molConcCombo.setItemText(0, _translate("MainWindow", "molar (M)"))
        self.molConcCombo.setItemText(1, _translate("MainWindow", "millimolar (mM)"))
        self.molConcCombo.setItemText(2, _translate("MainWindow", "micromolar (μM)"))
        self.molConcCombo.setItemText(3, _translate("MainWindow", "nanomolar (nM)"))
        self.molConcCombo.setItemText(4, _translate("MainWindow", "picomolar (pM)"))
        self.label_19.setText(_translate("MainWindow", "Molecular weight"))
        self.label_5.setText(_translate("MainWindow", "g"))
        self.molVolCombo.setItemText(0, _translate("MainWindow", "liters (L)"))
        self.molVolCombo.setItemText(1, _translate("MainWindow", "milliliters (mL)"))
        self.molVolCombo.setItemText(2, _translate("MainWindow", "microliters (μL)"))
        self.molClearButton.setToolTip(_translate("MainWindow", "Clear all fields"))
        self.molClearButton.setText(_translate("MainWindow", "..."))
        self.molCopyButton.setToolTip(_translate("MainWindow", "Copy"))
        self.molCopyButton.setText(_translate("MainWindow", "..."))
        self.molDbAddButton.setToolTip(_translate("MainWindow", "Save to database"))
        self.molDbAddButton.setText(_translate("MainWindow", "..."))
        self.molDbDelButton.setToolTip(_translate("MainWindow", "Delete from database"))
        self.molDbDelButton.setText(_translate("MainWindow", "..."))
        self.label_4.setText(_translate("MainWindow", "g / mol"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "Molar solution"))
        self.label_10.setText(_translate("MainWindow", "Final volume"))
        self.label.setText(_translate("MainWindow", "Required volume :"))
        self.label_22.setText(_translate("MainWindow", "Solution name"))
        self.dilV2Combo.setItemText(0, _translate("MainWindow", "liters (L)"))
        self.dilV2Combo.setItemText(1, _translate("MainWindow", "milliliters (mL)"))
        self.dilV2Combo.setItemText(2, _translate("MainWindow", "microliters (μL)"))
        self.dilC2Combo.setItemText(0, _translate("MainWindow", "molar (M)"))
        self.dilC2Combo.setItemText(1, _translate("MainWindow", "millimolar (mM)"))
        self.dilC2Combo.setItemText(2, _translate("MainWindow", "micromolar (μM)"))
        self.dilC2Combo.setItemText(3, _translate("MainWindow", "nanomolar (nM)"))
        self.dilC2Combo.setItemText(4, _translate("MainWindow", "picomolar (pM)"))
        self.label_16.setText(_translate("MainWindow", "Final concentration"))
        self.label_6.setText(_translate("MainWindow", "Stock concentration"))
        self.dilClearButton.setToolTip(_translate("MainWindow", "Clear all fields"))
        self.dilClearButton.setText(_translate("MainWindow", "..."))
        self.dilC1Combo.setItemText(0, _translate("MainWindow", "molar (M)"))
        self.dilC1Combo.setItemText(1, _translate("MainWindow", "millimolar (mM)"))
        self.dilC1Combo.setItemText(2, _translate("MainWindow", "micromolar (μM)"))
        self.dilC1Combo.setItemText(3, _translate("MainWindow", "nanomolar (nM)"))
        self.dilC1Combo.setItemText(4, _translate("MainWindow", "picomolar (pM)"))
        self.dilDbDelButton.setToolTip(_translate("MainWindow", "Delete from database"))
        self.dilDbDelButton.setText(_translate("MainWindow", "..."))
        self.dilDbAddButton.setToolTip(_translate("MainWindow", "Save to database"))
        self.dilDbAddButton.setText(_translate("MainWindow", "..."))
        self.dilResultCombo.setItemText(0, _translate("MainWindow", "liters (L)"))
        self.dilResultCombo.setItemText(1, _translate("MainWindow", "milliliters (mL)"))
        self.dilResultCombo.setItemText(2, _translate("MainWindow", "microliters (μL)"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Solution dilution"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Notes"))
        self.displayFormulaBox.setText(_translate("MainWindow", "Display current formula"))
        self.escapeKeyBox.setText(_translate("MainWindow", "Quit with escape key"))
        self.copyClipboardBox.setText(_translate("MainWindow", "Copy to clipboard"))
        self.copyNotesBox.setText(_translate("MainWindow", "Copy to notes"))
        self.resetButton.setText(_translate("MainWindow", "Reset to default"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("MainWindow", "Settings"))



#!/usr/bin/python3
import pathlib
import shutil
import sys
from PyQt5 import QtDBus

try:
    src = pathlib.Path(__file__).parents[1].joinpath("__id__.py")
    dst = pathlib.Path(__file__).parents[0].joinpath("__id__.py")
    shutil.copyfile(src, dst)
except FileNotFoundError:
    pass

try:
    from .__id__ import ID, HELP
except ImportError:
    from __id__ import ID, HELP


def main():
    service = f"org.{ID}"
    path = f"/org/{ID}"
    bus = QtDBus.QDBusConnection.sessionBus()
    interface = QtDBus.QDBusInterface(service, path, "", bus)

    cmd = sys.argv[1:]
    if not cmd or "--help" in cmd or "-h" in cmd:
        for h in HELP:
            print(h)

    elif interface.isValid():
        interface.call("ParseCommands", cmd)
        sys.exit(0)

    else:
        try:
            app = __import__(f"{ID}.main", fromlist=["main"])
        except ImportError:
            import main as app
        app.main(cmd)


if __name__ == '__main__':
    main()



#!/usr/bin/python3
import setuptools
import setuptools.command.build_py
import shutil
import sys
from pathlib import Path

LOCAL = str(Path(__file__).parents[0])
sys.path.append(LOCAL)
from __id__ import *


class ShortcutLinux(setuptools.command.build_py.build_py):
    def run(self):
        for s in SHORTCUTS:
            name, title = s
            filename = f"{ID}-{name}" if name else ID
            cmd = f"{ID} --{name}" if name else ID

            with open(Path(LOCAL) / f"{filename}.desktop", "w") as f:
                f.write("[Desktop Entry]\n")
                f.write(f"Name={title}")
                f.write("Type=Application\n")
                f.write("Categories=Utility;\n")
                f.write(f"Icon={filename}\n")
                f.write(f"Exec={cmd}\n")
        setuptools.command.build_py.build_py.run(self)


class ShortcutWindows(setuptools.command.build_py.build_py):
    def run(self):
        try:
            import sysconfig
            from win32com.client import Dispatch
            from win32com.shell import shell, shellcon

            desktop_dir = shell.SHGetFolderPath(0, shellcon.CSIDL_DESKTOP, None, 0)
            for s in SHORTCUTS:
                name, title = s
                filename = f"{ID}-{name}" if name else ID
                cmd = f"{ID}.exe --{name}" if name else f"{ID}.exe"

                shortcut = Path(desktop_dir) / f"{title}.lnk"
                icon = Path(sysconfig.get_path("data")) / "win32-icons" / f"{filename}.ico"
                exe = Path(sysconfig.get_path("scripts")) / cmd

                sh = Dispatch("WScript.Shell")
                shortcut = sh.CreateShortCut(str(shortcut))
                shortcut.IconLocation = str(icon)
                shortcut.Targetpath = str(exe)
                shortcut.save()
        except ModuleNotFoundError:
            print("pywin32 import error: could not create a desktop shortcut")
        setuptools.command.build_py.build_py.run(self)


def copy_id():
    src = Path(LOCAL) / "__id__.py"
    dst = Path(LOCAL) / ID / "__id__.py"
    shutil.copyfile(src, dst)


def fetch_df():
    data_files = []
    win32_icons = []
    linux_icons = []
    linux_links = []

    for s in SHORTCUTS:
        name, title = s
        name = f"{ID}-{name}" if name else ID
        ico_path = Path() / ID / "ui" / "icons" / f"{name}.ico"
        svg_path = Path() / ID / "ui" / "icons" / f"{name}.svg"
        lnk_path = Path() / f"{name}.desktop"

        if ico_path.is_file:
            win32_icons.append(str(ico_path))

        if svg_path.is_file:
            linux_icons.append(str(svg_path))

        if lnk_path.is_file:
            linux_links.append(f"{name}.desktop")

    if win32_icons:
        data_files += [("win32-icons", win32_icons)]

    if linux_icons:
        data_files += [
            ("share/icons/hicolor/scalable/apps", linux_icons),
            ("share/applications", linux_links),
        ]
    return data_files


def setup():
    dependancies = DEPENDANCIES
    try:
        from PyQt5 import uic
        uic.compileUiDir(Path(ID) / "ui")
    except ImportError:
        dependancies.append("pyqt5")

    data_files = fetch_df()
    if sys.platform == "win32":
        cmdclass = {"build_py": ShortcutWindows}
    else:
        cmdclass = {"build_py": ShortcutLinux}

    setuptools.setup(
        name=ID,
        version=VERSION,
        description=DESCRIPTION,
        keywords=KEYWORDS,
        author=AUTHOR,
        url=URL,
        classifiers=CLASSIFIERS,
        install_requires=dependancies,
        cmdclass=cmdclass,
        data_files=data_files,
        packages=setuptools.find_packages(),
        entry_points={"gui_scripts": [f"{ID}={ID}:main"]},
    )


if __name__ ==  '__main__':
    copy_id()
    setup()



#!/usr/bin/python3
import os ##
from pathlib import Path
import pandas
import re
import shutil
import sys

from pathlib import Path
from pandas.api.types import is_string_dtype
from pandas.api.types import is_numeric_dtype
from PyQt5 import QtWidgets, QtCore, QtGui, uic

try:
    from .ui import peak_ui
    from .__id__ import ID
    from .backend import cli, database, peak_adapters
except ImportError:
    from __id__ import ID
    from backend import cli, database, peak_adapters

SET_FILE = Path.home() / ".config" / ID / "settings.json"
TMP_FILE = Path.home() / ".config" / ID / "_tmp.xlsx"
LOCAL = str(Path(__file__).parents[0])


class ConvertThread(QtCore.QObject):
    busy = QtCore.pyqtSignal(bool)
    status = QtCore.pyqtSignal(str, str)
    success = QtCore.pyqtSignal()

    def __init__(self, parent):
        super().__init__()
        self.ui = parent.ui
        self.name = ""

    def _convert(self, files, output):
        pos = iter(("A1", "J1", "A15", "J15"))
        spectrum_type = self.ui.typeBox.currentText()
        stats_min = self.ui.statsMinBox.value()
        stats_max = self.ui.statsMaxBox.value()
        focus_min = self.ui.focusMinBox.value()
        focus_max = self.ui.focusMaxBox.value()
        labels = \
        {
            "x": self.ui.xLine.text(),
            "y": self.ui.yLine.text(),
            "stats title": self.ui.titleStatsLine.text(),
            "stats x": self.ui.xStatsLine.text(),
            "stats y": self.ui.yStatsLine.text(),
        }

        if spectrum_type == "Cary WinUV (v3)":
            sheet = peak_adapters.UVSheet(files, labels)
        elif spectrum_type == "OMNIC for Dispertive Raman (v8)":
            sheet = peak_adapters.RamanSheet(files, labels)
        if self.ui.statsBox.isChecked():
            sheet.add_stats(x_min=stats_min, x_max=stats_max)
        sheet.add_chart(pos=next(pos), peaks=False)
        sheet.add_chart(pos=next(pos), peaks=True)

        if self.ui.focusBox.isChecked():
            sheet.add_chart(pos=next(pos), x_min=focus_min, x_max=focus_max, peaks=False)
            sheet.add_chart(pos=next(pos), x_min=focus_min, x_max=focus_max, peaks=True)
        sheet.save(output)

    @QtCore.pyqtSlot(list, str)
    def convert(self, files, output):
        self.busy.emit(False)
        try:
            self._convert(files, output)
            if len(files) == 1:
                self.name = str(Path(files[0]).stem)
            self.success.emit()
        except pandas.errors.ParserError:
            self.status.emit("red", "Conversion failed: ParserError. Wrong data type ?")
        except Exception as error:
            self.status.emit("red", str(error))
        self.busy.emit(True)


class Main(QtWidgets.QMainWindow):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self._uiInit()
        self._settingsInit()
        self._settingsLoad()

        self.worker = ConvertThread(self)
        self.workerThread = QtCore.QThread()
        self.worker.moveToThread(self.workerThread)
        self.worker.success.connect(self.save)
        self.worker.status.connect(self.statusUpdate)
        self.worker.busy.connect(self.tree.setEnabled)
        self.worker.busy.connect(self.ui.convertButton.setEnabled)
        self.workerThread.start()

    def _convert(self):
        files = []
        for item in range(self.tree.topLevelItemCount()):
            item = self.tree.topLevelItem(item)
            files.append(item.text(0))
        self.tree.clearSelection()
        self.statusUpdate("default", "Conversion in progress...")
        a1 = QtCore.Q_ARG(list, files)
        a2 = QtCore.Q_ARG(str, str(TMP_FILE))
        QtCore.QMetaObject.invokeMethod(self.worker, "convert", QtCore.Qt.QueuedConnection, a1, a2)

    def _clear(self):
        self.tree.clear()
        self.treeItemHook()

    def _settingsInit(self):
        self.settings = database.Database(SET_FILE)
        self.settings.fields = [self.ui.focusBox,
                                self.ui.statsBox,
                                self.ui.statsMinBox,
                                self.ui.statsMaxBox,
                                self.ui.focusMinBox,
                                self.ui.focusMaxBox,
                                self.ui.xLine,
                                self.ui.yLine,
                                self.ui.titleStatsLine,
                                self.ui.xStatsLine,
                                self.ui.yStatsLine]

    def _settingsLoad(self):
        last = self.settings.db["peak"]["last profile"]
        self._profileLoad(last)
        self.ui.typeBox.setCurrentText(last)

    def _settingsSave(self):
        current = self.ui.typeBox.currentText()
        db = self.settings.db["peak"]["profiles"][current]
        db.setdefault(current, {})
        self.settings.db["peak"]["autodetect"] = self.ui.autodetectBox.isChecked()
        self.settings.db["peak"]["last profile"] = current
        self.settings.save(db)

    def _profileLoad(self, profile):
        current = self.ui.typeBox.currentText()
        db = self.settings.db["peak"]["profiles"][current]
        self.settings.load(db)
        self.ui.autodetectBox.setChecked(self.settings.db["peak"]["autodetect"])
        self.ui.typeBox.clearFocus()

    def _saveDialog(self, name):
        dialog = QtWidgets.QFileDialog(self, "Save file as")#, name)
        dialog.setAcceptMode(QtWidgets.QFileDialog.AcceptSave)
        dialog.setNameFilter("*.xlsx")

        current = self.ui.typeBox.currentText()
        directory = self.settings.db["peak"]["profiles"][current]["output path"]
        dialog.setDirectory(directory)
        dialog.selectFile(name)

        if dialog.exec_():
            output = dialog.selectedFiles()[0]
            if not output.endswith(".xlsx"):
                output += ".xlsx"
            return output
        return None

    def _typeDetect(self, path):
        try:
            df = pandas.read_csv(path, sep=",", encoding="latin-1")
        except pandas.errors.ParserError:
            df = pandas.read_csv(path, sep=";", encoding="latin-1")

        strings, nums = [], []
        for index, col in enumerate(df.columns):
            if index > 1: break
            else:
                strings.append(is_string_dtype(df[col].dtype))
                nums.append(is_numeric_dtype(df[col].dtype))

        # Omnic: contain only floats
        if True not in strings:
            return "OMNIC for Dispertive Raman (v8)"

        # Cary WinUV: the two first row are strings
        elif True not in nums:
            return "Cary WinUV (v3)"

        return None

    def _uiInit(self):
        try:
            self.ui = peak_ui.Ui_MainWindow()
            self.ui.setupUi(self)
        except NameError:
            path = Path(LOCAL).parents[0] / "ui" / "peak_ui.ui"
            self.ui = uic.loadUi(path, self)

        path = str(Path(LOCAL).parents[0] / "ui" / "icons" / "qtlab-peak.svg")
        icon = QtGui.QIcon(path)
        self.setWindowIcon(icon)
        self.setWindowTitle("Peakcell: CSV to Excel Converter")

        self.tree = Tree(self)
        self.ui.treeLayout.insertWidget(1, self.tree)
        self.ui.typeBox.currentTextChanged.connect(self._profileLoad)
        self.ui.convertButton.clicked.connect(self._convert)
        self.ui.quitButton.clicked.connect(self.close)
        self.ui.clearButton.clicked.connect(self._clear)

        self.ui.statusRightLabel = QtWidgets.QLabel()
        self.ui.statusBar = QtWidgets.QStatusBar()
        self.ui.statusBar.addPermanentWidget(self.ui.statusRightLabel)
        self.ui.statusBar.setStyleSheet("QStatusBar::item { border: 0 }")
        self.setStatusBar(self.ui.statusBar)

        self.tree.setFocus(True)
        self.setSaveEnabled(False)
        self.show()

    def treeItemHook(self):
        count = self.tree.topLevelItemCount()
        if count == 0:
            self.setSaveEnabled(False)
        elif count == 1:
            if self.ui.autodetectBox.isChecked():
                item = self.tree.topLevelItem(0)
                dataType = self._typeDetect(path=item.text(0))
                self.ui.typeBox.setCurrentText(dataType)

        if count > 0:
            self.statusUpdate("default")
            self.setSaveEnabled(True)
            self.tree.setFocus(True)

    def setSaveEnabled(self, state):
        self.ui.convertButton.setEnabled(state)

    @QtCore.pyqtSlot(dict)
    def cli(self, cmd):
        if "quit" in cmd:
            self.parent.quit()

    @QtCore.pyqtSlot()
    def save(self):
        output = self._saveDialog(self.worker.name)
        if output:
            shutil.move(TMP_FILE, output)

            # Remember output path
            current = self.ui.typeBox.currentText()
            dirname = str(Path(output).parents[0])
            self.settings.db["peak"]["profiles"][current]["output path"] = dirname

            self.statusUpdate("green", "Conversion successful", output)
            self._settingsSave()
            self.setSaveEnabled(False)
            self.tree.clear()
        else:
            self.statusUpdate("default", "Aborted")
        self.tree.setFocus(True)

    @QtCore.pyqtSlot(str, str)
    def statusUpdate(self, color, left="", right=""):
        if color == "default":
            self.ui.statusBar.setStyleSheet("QStatusBar::item { border: 0 }")
        else:
            palettes = \
            {
                "green": {"bg": "#C6EFCE", "fg": "#004000"},
                "red": {"bg": "#FFC7CE", "fg": "#9C0006"}
            }
            bg = QtGui.QColor(palettes[color]["bg"])
            fg = QtGui.QColor(palettes[color]["fg"])

            palette = self.ui.statusBar.palette()
            palette.setColor(QtGui.QPalette.Window, bg)
            palette.setColor(QtGui.QPalette.WindowText, fg)
            self.ui.statusBar.setPalette(palette)
        self.ui.statusBar.showMessage(left)
        self.ui.statusRightLabel.setText(right)


class Tree(QtWidgets.QTreeWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.setHeaderHidden(True)
        self.setAlternatingRowColors(True)
        self.setIndentation(6)
        self.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.viewport().installEventFilter(self)

    def _add(self, path):
        if path.suffix.lower() == ".csv":
            item = TreeItem(self)
            item.setText(0, str(path))
            index = self.currentIndex().row()

            if index == -1: index = 0
            self.insertTopLevelItem(index, item)
            item.setSelected(True)
            self.parent.treeItemHook()

    def _openDialog(self):
        dialog = QtWidgets.QFileDialog(self, "Open CSV files")
        dialog.setAcceptMode(QtWidgets.QFileDialog.AcceptOpen)
        dialog.setFileMode(QtWidgets.QFileDialog.ExistingFiles)
        dialog.setNameFilter("*.csv *.CSV")

        current = self.parent.ui.typeBox.currentText()
        current = self.parent.settings.db["peak"]["profiles"].get(current)
        if current:
            directory = current["input path"]
            dialog.setDirectory(directory)

        if dialog.exec_():
            for f in dialog.selectedFiles():
                self._add(Path(f))

            # Remember the new input path
            current = self.parent.ui.typeBox.currentText()
            dirname = str(Path(f).parents[0])
            self.parent.settings.db["peak"]["profiles"][current]["input path"] = dirname

    def _translateHexCodes(self, string):
        """Find and replace hex codes from a string
        Replace '%5BFF1~10%5D.mp3 %21' to '[FF1~10].mp3 !'
        """
        # %\d{2}       Patterns starting with a %, followed by two digit
        # %\d[a-fA-F]  Patterns starting with a %, followed by one digit and one letter from a to F
        hexChars = re.findall(r"%\d{2}|%\d[a-fA-F]", string)
        for code in hexChars:
            litteral = code.replace("%", "0x")
            litteral = chr(eval(litteral))
            string = string.replace(code, litteral)
        return string

    def dragEnterEvent(self, event):
        if event.mimeData().hasUrls():
            event.acceptProposedAction()
        QtWidgets.QTreeWidget.dragEnterEvent(self, event)

    def dropEvent(self, event):
        if event.mimeData().hasUrls():
            for url in event.mimeData().urls():
                path = url.toString(QtCore.QUrl.PreferLocalFile)
                path = self._translateHexCodes(path)
                path = Path(path)
                if path.is_file():
                    self._add(path)
                elif path.is_dir():
                    for p in path.rglob("*"):
                        if p.is_file():
                            self._add(p)
        QtWidgets.QTreeWidget.dropEvent(self, event)

    def eventFilter(self, obj, event):
        if event.type() == QtCore.QEvent.MouseButtonPress:
            if self.topLevelItemCount() == 0:
                self._openDialog()
        return QtCore.QObject.event(obj, event)

    def keyPressEvent(self, event):
        key = event.key()
        if key == QtCore.Qt.Key_Delete:
            for item in self.selectedItems():
                index = self.indexOfTopLevelItem(item)
                self.takeTopLevelItem(index)
        self.parent.treeItemHook()

    def paintEvent(self, event):
        if self.model() and self.model().rowCount(self.rootIndex()) > 0:
            QtWidgets.QTreeWidget.paintEvent(self, event)
            return
        p = QtGui.QPainter(self.viewport())
        p.drawText(self.rect(), QtCore.Qt.AlignCenter, "Drop CSV files here")


class TreeItem(QtWidgets.QTreeWidgetItem):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.setFlags(self.flags() &~ QtCore.Qt.ItemIsDropEnabled)
